import React from 'react';
import { render, screen } from '@testing-library/react';
import {
  ProblemDropdown,
  ProblemDropdownProps,
  ProblemGroupDropdown,
  ProblemGroupDropdownProps,
} from './ProblemDropdown';
import userEvent from '@testing-library/user-event';
import config from '../../__mocks__/config.json';

const translation = config.localisations.en.translation;
const problemGroups = translation.problemGroups;
const problems = problemGroups.technical.problems;
const selectProblemGroup = translation.selectProblemGroup;
const selectProblem = translation.selectProblem;
const mockSetProblem: CallableFunction = jest.fn();

const problemDropdownProps: ProblemDropdownProps = {
  id: 'problem',
  intro: problemGroups.technical.problemDescribe,
  problems,
  selectProblem,
  problem: '', // none selected
  setProblem: mockSetProblem,
};

const problemGroupDropdownProps: ProblemGroupDropdownProps = {
  id: 'problemGroup',
  intro: translation.problemDescribe,
  problemGroups,
  selectProblemGroup,
  problemGroup: '', // none selected
  setProblemGroup: mockSetProblem,
};

const getFirstItem = (
  props: ProblemDropdownProps | ProblemGroupDropdownProps,
) => {
  if ('problems' in props) {
    return ['problem', Object.keys(props.problems)[0]];
  }
  return ['problemGroup', Object.keys(props.problemGroups)[0]];
};

const getComponentByProps = (
  props: ProblemDropdownProps | ProblemGroupDropdownProps,
) => {
  if ('problems' in props) return ProblemDropdown;
  return ProblemGroupDropdown;
};

describe.each([
  [
    'ProblemDropdown', // Name for decribe()
    'problems', // Name of item type
    problemDropdownProps, // Props to render with
  ],
  ['ProblemGroupDropdown', 'problemgroups', problemGroupDropdownProps],
])('<%s>', (_, type, props) => {
  const Component = getComponentByProps(props);
  const firstProblem = getFirstItem(props);
  it(`renders a list of ${type}`, () => {
    render(<Component {...(props as any)} />);
    // Check the default value is selected
    const elSelect = screen.getByRole('combobox');
    if ("selectProblem" in props) {
      expect(screen.getByText(props.intro)).toBeInTheDocument();
      expect(elSelect).toHaveDisplayValue(props.selectProblem);
    } else {
      expect(elSelect).toHaveDisplayValue(props.selectProblemGroup);
    }
    expect(elSelect).toHaveValue('');
    // Select the first option and see if it is selected
    userEvent.selectOptions(elSelect, firstProblem[1]);
    expect(mockSetProblem).toBeCalledWith(firstProblem[1]);
  });

  it(`renders a list of ${type}, first problem selected top-down`, () => {
    const firstProblemSelection = Object.fromEntries([firstProblem]);
    render(<Component {...{ ...props, ...firstProblemSelection }} />);
    // Check the prop value is selected
    const elSelect = screen.getByRole('combobox');
    expect(elSelect).toHaveValue(firstProblem[1]);
  });
});
