import React from 'react';
import type { Problem, ProblemGroup } from 'src/types';

export interface ProblemDropdownProps extends GenericProblemDropdownProps {
  intro: string;
  problems: Record<string, Problem>;
}

export const ProblemDropdown: React.FC<ProblemDropdownProps> = (
  props: ProblemDropdownProps,
) => {
  return <GenericProblemDropdown {...props} />;
};

export interface ProblemGroupDropdownProps {
  id: string;
  intro: string;
  selectProblemGroup: string;
  problemGroup: string;
  setProblemGroup: CallableFunction;
  problemGroups: Record<string, ProblemGroup>;
}

export const ProblemGroupDropdown: React.FC<ProblemGroupDropdownProps> = ({
  id,
  intro,
  selectProblemGroup,
  problemGroup,
  setProblemGroup,
  problemGroups,
}: ProblemGroupDropdownProps) => {
  return (
    <GenericProblemDropdown
      id={id}
      intro={intro}
      problem={problemGroup}
      problems={problemGroups}
      selectProblem={selectProblemGroup}
      setProblem={setProblemGroup}
    />
  );
};

export interface GenericProblemDropdownProps {
  id: string;
  intro: string;
  selectProblem: string;
  problem: string;
  problems: Record<string, Problem | ProblemGroup>;
  setProblem: CallableFunction;
}

export const GenericProblemDropdown: React.FC<GenericProblemDropdownProps> = ({
  id,
  intro,
  selectProblem,
  problems,
  problem,
  setProblem,
}: GenericProblemDropdownProps) => {
  return (
    <div className="field">
      <label htmlFor={id}>{intro}</label>
      <select
        id={id}
        value={problem}
        onChange={(e) => setProblem(e.target.value)}
      >
        <option key="_default" value="">
          {selectProblem}
        </option>
        {Object.entries(problems).map(([problemKey, problemObject]) => (
          <option key={problemKey} value={problemKey}>
            {problemObject.description}
          </option>
        ))}
      </select>
    </div>
  );
};
